.. jscatter documentation master file, created by
   sphinx-quickstart on Thu Apr 24 23:56:32 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

jscatter's documentation
========================

.. include:: ../../README.rst
   :end-before:  **Intention and Remarks**

.. automodule:: jscatter

jscatter package contents
==========================
.. currentmodule::jscatter
    

.. toctree:: 
   :maxdepth: 3
   :numbered:

   help
   dataArray
   dataList
   formel
   sas
   formfactor
   structurefactor
   dynamic
   dls
   parallel
   GracePlot
   mpl
   examples
   Extending
   tips
   Remarks




Installation
============
.. include:: ../../INSTALLATION.txt


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

